validate_indexes_supported

Function validate_indexes_supported 

pub(super) fn validate_indexes_supported(
    fqn: &FullyQualifiedName,
    stmt: &Statement,
    indexes: &[CreateIndexStatement<Raw>],
    offsets: &[usize],
    errors: &mut Vec<ValidationError>,
)
Validates that indexes are only defined on views and materialized views.

Tables and sources are storage objects whose lifecycle mz-deploy manages through apply; an index on one is not supported.